@@ -1,5 +1,5 @@
 #! /usr/bin/env python3
-# $Id: test_parser.py 9047 2022-03-17 13:40:11Z milde $
+# $Id: test_parser.py 9308 2022-12-13 21:45:23Z milde $
 # Author: Stefan Rank <strank(AT)strank(DOT)info>
 # Copyright: This module has been placed in the public domain.
 
@@ -7,8 +7,15 @@
 Tests for basic functionality of parser classes.
 """
 
+from pathlib import Path
+import sys
 import unittest
 
+if __name__ == '__main__':
+    # prepend the "docutils root" to the Python library path
+    # so we import the local `docutils` package.
+    sys.path.insert(0, str(Path(__file__).resolve().parents[2]))
+
 from docutils import parsers, utils, frontend
 
 
