@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 
-# $Id: test_date.py 9078 2022-06-17 11:31:40Z milde $
+# $Id: test_date.py 9277 2022-11-26 23:15:13Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -8,18 +8,34 @@
 Tests for the misc.py "date" directive.
 """
 
-if __name__ == '__main__':
-    import __init__  # noqa: F401
-from test_parsers import DocutilsTestSupport
 import time
+from pathlib import Path
+import sys
+import unittest
+
+if __name__ == '__main__':
+    # prepend the "docutils root" to the Python library path
+    # so we import the local `docutils` package.
+    sys.path.insert(0, str(Path(__file__).resolve().parents[4]))
 
 from docutils.io import _locale_encoding  # noqa
+from docutils.frontend import get_default_settings
+from docutils.parsers.rst import Parser
+from docutils.utils import new_document
 
 
-def suite():
-    s = DocutilsTestSupport.ParserTestSuite()
-    s.generateTests(totest)
-    return s
+class ParserTestCase(unittest.TestCase):
+    def test_parser(self):
+        parser = Parser()
+        settings = get_default_settings(Parser)
+        settings.warning_stream = ''
+        for name, cases in totest.items():
+            for casenum, (case_input, case_expected) in enumerate(cases):
+                with self.subTest(id=f'totest[{name!r}][{casenum}]'):
+                    document = new_document('test data', settings.copy())
+                    parser.parse(case_input, document)
+                    output = document.pformat()
+                    self.assertEqual(output, case_expected)
 
 
 totest = {}
@@ -64,7 +80,7 @@ Today's date is |date|.
 # some locales return non-ASCII characters for names of days or months
 # ensure the directive handles them correctly
 if _locale_encoding in ('utf-8', 'utf8', 'latin-1', 'iso-8859-1'):
-    totest['decode date'] = [
+    totest['decode_date'] = [
     ["""\
 .. |date| date:: täglich
 """,
@@ -76,5 +92,4 @@ if _locale_encoding in ('utf-8', 'utf8', 'latin-1', 'iso-8859-1'):
     ]
 
 if __name__ == '__main__':
-    import unittest
-    unittest.main(defaultTest='suite')
+    unittest.main()
